@@ -3,7 +3,6 @@
 """
 
 import asyncio
-import builtins
 import os
 import re
 
@@ -199,27 +198,27 @@ class BbTrackerJobs(TrackerJobsBase):
         the user
         """
         if self.is_movie_release:
-            if getattr(self.cli_args, 'title', False):
+            if self.options.get('title', False):
                 return ('imdb_job', 'movie_title_job')
-            elif getattr(self.cli_args, 'description', False):
+            elif self.options.get('description', False):
                 return ('imdb_job', 'movie_description_job')
-            elif getattr(self.cli_args, 'poster', False):
+            elif self.options.get('poster', False):
                 return ('imdb_job', 'movie_poster_job')
-            elif getattr(self.cli_args, 'release_info', False):
+            elif self.options.get('release_info', False):
                 return ('movie_release_info_job',)
-            elif getattr(self.cli_args, 'tags', False):
+            elif self.options.get('tags', False):
                 return ('imdb_job', 'movie_tags_job')
 
         elif self.is_series_release:
-            if getattr(self.cli_args, 'title', False) or getattr(self.cli_args, 'release_info', False):
+            if self.options.get('title', False) or self.options.get('release_info', False):
                 # Series title and release_info are combined
                 return ('tvmaze_job', 'series_title_job')
-            elif getattr(self.cli_args, 'description', False):
+            elif self.options.get('description', False):
                 return ('tvmaze_job', 'mediainfo_job', 'screenshots_job',
                         'upload_screenshots_job', 'series_description_job')
-            elif getattr(self.cli_args, 'poster', False):
+            elif self.options.get('poster', False):
                 return ('tvmaze_job', 'series_poster_job')
-            elif getattr(self.cli_args, 'tags', False):
+            elif self.options.get('tags', False):
                 return ('tvmaze_job', 'series_tags_job')
 
         return ()
@@ -279,36 +278,41 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_year_job(self):
         self.imdb_job.signal.register('output', self.fill_in_movie_year)
+        if self.release_name.year == 'UNKNOWN_YEAR':
+            guessed_year = ''
+        else:
+            guessed_year = self.release_name.year
         return jobs.dialog.TextFieldJob(
             name='movie-year',
             label='Year',
             condition=self.make_job_condition('movie_year_job', release.ReleaseType.movie),
-            text=self.release_name.year,
+            text=guessed_year,
             validator=self.movie_year_validator,
             **self.common_job_args,
         )
 
     def movie_year_validator(self, text):
-        # Raises ValueError if not a valid year
+        # Raise ValueError if not a valid year
         self.release_name.year = text
+        # release_name.year is now "UNKNOWN_YEAR" if year is required but not known
+        if self.release_name.year == 'UNKNOWN_YEAR':
+            raise ValueError('Failed to autodetect year.')
 
     def fill_in_movie_year(self, imdb_id):
-        default_text = self.release_name.year
         coro = self.imdb.year(imdb_id)
         task = self.movie_year_job.fetch_text(
             coro=coro,
-            default_text=default_text,
             finish_on_success=True,
         )
         self.movie_year_job.add_task(task)
 
     @cached_property
     def movie_resolution_job(self):
-        return self.make_choices_job(
+        return self.make_choice_job(
             name='movie-resolution',
             label='Resolution',
             condition=self.make_job_condition('movie_resolution_job', release.ReleaseType.movie),
-            autodetect_value=self.release_info_resolution,
+            autodetected=self.release_info_resolution,
             autofinish=True,
             options=(
                 {'label': '4320p', 'value': '2160p', 'regex': re.compile(r'4320p')},
@@ -319,6 +323,8 @@ class BbTrackerJobs(TrackerJobsBase):
                 {'label': '720i', 'value': '720i', 'regex': re.compile(r'720i')},
                 {'label': '576p', 'value': '480p', 'regex': re.compile(r'576p')},
                 {'label': '576i', 'value': '480i', 'regex': re.compile(r'576i')},
+                {'label': '540p', 'value': '480p', 'regex': re.compile(r'540p')},
+                {'label': '540i', 'value': '480i', 'regex': re.compile(r'540i')},
                 {'label': '480p', 'value': '480p', 'regex': re.compile(r'480p')},
                 {'label': '480i', 'value': '480i', 'regex': re.compile(r'480i')},
                 {'label': 'SD', 'value': 'SD', 'regex': re.compile(r'SD')},
@@ -327,11 +333,11 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_source_job(self):
-        return self.make_choices_job(
+        return self.make_choice_job(
             name='movie-source',
             label='Source',
             condition=self.make_job_condition('movie_source_job', release.ReleaseType.movie),
-            autodetect_value=self.release_name.source,
+            autodetected=self.release_name.source,
             autofinish=True,
             options=(
                 {'label': 'BluRay', 'value': 'BluRay', 'regex': re.compile('^BluRay')},  # BluRay or BluRay Remux
@@ -359,11 +365,11 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_audio_codec_job(self):
-        return self.make_choices_job(
+        return self.make_choice_job(
             name='movie-audio-codec',
             label='Audio Codec',
             condition=self.make_job_condition('movie_audio_codec_job', release.ReleaseType.movie),
-            autodetect_value=self.release_info_audio_format,
+            autodetected=self.release_info_audio_format,
             autofinish=True,
             options=(
                 {'label': 'AAC', 'value': 'AAC', 'regex': re.compile(r'^AAC$')},
@@ -382,11 +388,11 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_video_codec_job(self):
-        return self.make_choices_job(
+        return self.make_choice_job(
             name='movie-video-codec',
             label='Video Codec',
             condition=self.make_job_condition('movie_video_codec_job', release.ReleaseType.movie),
-            autodetect_value=self.release_name.video_format,
+            autodetected=self.release_name.video_format,
             autofinish=True,
             options=(
                 {'label': 'x264', 'value': 'x264', 'regex': re.compile(r'x264')},
@@ -403,11 +409,11 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_container_job(self):
-        return self.make_choices_job(
+        return self.make_choice_job(
             name='movie-container',
             label='Container',
             condition=self.make_job_condition('movie_container_job', release.ReleaseType.movie),
-            autodetect_value=fs.file_extension(video.first_video(self.content_path)),
+            autodetected=fs.file_extension(video.first_video(self.content_path)),
             autofinish=True,
             options=(
                 {'label': 'AVI', 'value': 'AVI', 'regex': re.compile(r'(?i:AVI)')},
@@ -820,14 +826,14 @@ class BbTrackerJobs(TrackerJobsBase):
                     poster_job.info = ''
 
     async def get_poster_file(self, poster_job, poster_url_getter):
-        if self.cli_args.poster_file:
+        if self.options.get('poster_file'):
             # Get poster from CLI argument
-            if re.search(r'^[a-z]+://', self.cli_args.poster_file):
+            if re.search(r'^[a-z]+://', self.options['poster_file']):
                 # CLI argument is URL
-                poster_url = self.cli_args.poster_file
+                poster_url = self.options['poster_file']
             else:
                 # CLI argument is file path
-                return self.cli_args.poster_file
+                return self.options['poster_file']
         else:
             # Get poster URL from webdb (e.g. "https://imdb.com/...jpg")
             poster_url = await poster_url_getter()
@@ -1132,22 +1138,6 @@ class BbTrackerJobs(TrackerJobsBase):
         else:
             return super().submission_ok
 
-    def get_job_output(self, job, slice=None):
-        if not job.is_finished:
-            raise RuntimeError(f'Unfinished job: {job.name}')
-        if slice is None:
-            slice = builtins.slice(None, None)
-        try:
-            return job.output[slice]
-        except IndexError:
-            raise RuntimeError(f'Job finished with insufficient output: {job.name}: {job.output}')
-
-    def get_job_attribute(self, job, attribute):
-        if not job.is_finished:
-            raise RuntimeError(f'Unfinished job: {job.name}')
-        else:
-            return getattr(job, attribute)
-
     @property
     def torrent_filepath(self):
         return self.get_job_output(self.create_torrent_job, slice=0)
@@ -1196,44 +1186,3 @@ class BbTrackerJobs(TrackerJobsBase):
     def post_data_screenshot_urls(self):
         urls = self.get_job_output(self.upload_screenshots_job)
         return {f'screenshot{i}': url for i, url in enumerate(urls, start=1)}
-
-    # Other stuff
-
-    def make_choices_job(self, name, label, options, condition=None,
-                         autodetect_value=None, autofinish=False):
-        """
-        Return :class:`~.jobs.dialog.ChoiceJob` instance
-
-        :param name: See :class:`~.jobs.dialog.ChoiceJob`
-        :param label: See :class:`~.jobs.dialog.ChoiceJob`
-        :param autodetect_value: Autodetected choice
-        :param options: Sequence of `(label, value, regex)` tuples. `label` is
-            presented to the user and `value` is available via
-            :attr:`~.jobs.dialog.ChoiceJob.choice` when this job is
-            finished. The first `regex` that matches `autodetect_value` is
-            visually marked as "autodetected" for the user.
-        :param condition: See ``condition`` for :class:`~.base.JobBase`
-        :param bool autofinish: Whether to choose the autodetected value with no
-            user-interaction
-        """
-        focused = None
-        choices = []
-        for option in options:
-            if not focused and option['regex'].search(autodetect_value):
-                choices.append((f'{option["label"]} (autodetected)', option['value']))
-                focused = choices[-1]
-                autofinish = autofinish and True
-            else:
-                choices.append((option['label'], option['value']))
-
-        job = jobs.dialog.ChoiceJob(
-            name=name,
-            label=label,
-            condition=condition,
-            choices=choices,
-            focused=focused,
-            **self.common_job_args,
-        )
-        if autofinish and focused:
-            job.choice = focused
-        return job
