@@ -2,6 +2,7 @@
 BbTracker class
 """
 
+import argparse
 import asyncio
 import re
 import urllib
@@ -16,6 +17,15 @@ import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
 
+def number_of_screenshots(value):
+    try:
+        return type(BbTrackerConfig.defaults['screenshots'])(value)
+    except ValueError as e:
+        # Raising ArgumentTypeError preserves the error message while raising
+        # ValueError produces a generic "invalid value" error message.
+        raise argparse.ArgumentTypeError(e)
+
+
 class BbTracker(TrackerBase):
     name = 'bb'
     label = 'bB'
@@ -24,6 +34,10 @@ class BbTracker(TrackerBase):
         ('--poster-file',): {
             'help': 'Path or URL to poster image',
         },
+        ('--screenshots', '-s'): {
+            'help': 'How many screenshots to make',
+            'type': number_of_screenshots,
+        },
         ('--title', '-t'): {
             'group': 'single-job',
             'help': 'Only generate title',
@@ -66,25 +80,25 @@ class BbTracker(TrackerBase):
 
     async def login(self):
         if not self.is_logged_in:
-            if not self.config.get('username'):
+            if not self.options.get('username'):
                 raise errors.RequestError('Login failed: No username configured')
-            elif not self.config.get('password'):
+            elif not self.options.get('password'):
                 raise errors.RequestError('Login failed: No password configured')
 
             login_url = urllib.parse.urljoin(
-                self.config['base_url'],
+                self.options['base_url'],
                 self._url_path['login'],
             )
 
             doc = html.parse('')
             while await self._work_around_login_bug(doc):
-                _log.debug('%s: Logging in as %r', self.name, self.config['username'])
+                _log.debug('%s: Logging in as %r', self.name, self.options['username'])
                 response = await http.post(
                     url=login_url,
                     user_agent=True,
                     data={
-                        'username': self.config['username'],
-                        'password': self.config['password'],
+                        'username': self.options['username'],
+                        'password': self.options['password'],
                         'login': 'Log In!',
                     },
                 )
@@ -150,7 +164,7 @@ class BbTracker(TrackerBase):
         if self.is_logged_in:
             _log.debug('%s: Logging out', self.name)
             logout_url = urllib.parse.urljoin(
-                self.config['base_url'],
+                self.options['base_url'],
                 self._url_path['logout'],
             )
             params = {'auth': self._auth_token}
@@ -159,7 +173,7 @@ class BbTracker(TrackerBase):
 
     async def get_announce_url(self):
         url = urllib.parse.urljoin(
-            self.config['base_url'],
+            self.options['base_url'],
             self._url_path['upload'],
         )
         _log.debug('%s: Getting announce URL from %s', self.name, url)
@@ -174,7 +188,7 @@ class BbTracker(TrackerBase):
 
     async def upload(self, tracker_jobs):
         _log.debug('Uploading %r', tracker_jobs.post_data)
-        upload_url = urllib.parse.urljoin(self.config['base_url'], self._url_path['upload'])
+        upload_url = urllib.parse.urljoin(self.options['base_url'], self._url_path['upload'])
         response = await http.post(
             url=upload_url,
             cache=False,
@@ -186,7 +200,7 @@ class BbTracker(TrackerBase):
 
         # Upload response should redirect to torrent page via "Location" header
         torrent_page_url = urllib.parse.urljoin(
-            self.config['base_url'],
+            self.options['base_url'],
             response.headers.get('Location', ''),
         )
         if urllib.parse.urlparse(torrent_page_url).path == self._url_path['torrent']:
