@@ -3,7 +3,6 @@ Generate all required metadata and upload to tracker
 """
 
 from .... import jobs, trackers, utils
-from . import argtypes
 from .base import CommandBase
 
 
@@ -19,11 +18,11 @@ class submit(CommandBase):
             # Default arguments for all tackers
             **{
                 'CONTENT': {
-                    'type': argtypes.content,
+                    'type': utils.argtypes.content,
                     'help': 'Path to release content',
                 },
                 ('--add-to', '-a'): {
-                    'type': argtypes.client,
+                    'type': utils.argtypes.client,
                     'metavar': 'CLIENT',
                     'help': ('Case-insensitive BitTorrent client name\n'
                              'Supported clients: ' + ', '.join(utils.btclients.client_names())),
@@ -60,9 +59,20 @@ class submit(CommandBase):
         return self.args.subcommand.lower()
 
     @utils.cached_property
-    def tracker_config(self):
-        """Dictionary of :attr:`tracker_name` section in trackers configuration file"""
-        return self.config['trackers'][self.tracker_name]
+    def tracker_options(self):
+        """
+        :attr:`tracker_name` section in trackers configuration file combined with
+        CLI arguments where CLI arguments take precedence unless their value is
+        `None`
+        """
+        config = self.config['trackers'][self.tracker_name]
+        cli_args = vars(self.args)
+        options = {}
+        options.update(config)
+        for k, v in cli_args.items():
+            if v is not None:
+                options[k] = v
+        return options
 
     @utils.cached_property
     def tracker(self):
@@ -72,8 +82,7 @@ class submit(CommandBase):
         """
         return trackers.tracker(
             name=self.tracker_name,
-            config=self.tracker_config,
-            cli_args=self.args,
+            options=self.tracker_options,
         )
 
     @utils.cached_property
@@ -83,6 +92,7 @@ class submit(CommandBase):
         of :mod:`.trackers`
         """
         return self.tracker.TrackerJobs(
+            options=self.tracker_options,
             content_path=self.args.CONTENT,
             tracker=self.tracker,
             image_host=self._get_imghost(),
@@ -93,11 +103,10 @@ class submit(CommandBase):
                 'cache_directory': self.cache_directory,
                 'ignore_cache': self.args.ignore_cache,
             },
-            cli_args=self.args,
         )
 
     def _get_imghost(self):
-        imghost_name = self.tracker_config.get('image_host', None)
+        imghost_name = self.tracker_options.get('image_host', None)
         if imghost_name:
             return utils.imghosts.imghost(
                 name=imghost_name,
@@ -106,7 +115,7 @@ class submit(CommandBase):
 
     def _get_btclient(self):
         btclient_name = (getattr(self.args, 'add_to', None)
-                         or self.tracker_config.get('add-to', None)
+                         or self.tracker_options.get('add-to', None)
                          or None)
         if btclient_name:
             return utils.btclients.client(
@@ -116,5 +125,5 @@ class submit(CommandBase):
 
     def _get_torrent_destination(self):
         return (getattr(self.args, 'copy_to', None)
-                or self.tracker_config.get('copy-to', None)
+                or self.tracker_options.get('copy-to', None)
                 or None)
