@@ -5,6 +5,7 @@ File system helpers
 import functools
 import os
 import re
+import time
 
 from .. import constants, errors
 from . import LazyModule, os_family, string
@@ -63,18 +64,23 @@ def projectdir(content_path, base=None):
     return path
 
 
-def limit_directory_size(path, max_total_size):
+def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
     """
     Delete oldest files (by access time) until maximum size is not exceeded
 
-    :func:`prune_empty_directories` is also called with `path`.
+    Empty files and directories are always deleted.
 
     :param path: Path to directory
     :param max_total_size: Maximum combined size of all files in `path` and its
         subdirectories
+    :param min_age: Preserve files that are younger than this
+    :type min_age: int or float
+    :param max_age: Preserve files that are older than this
+    :type max_age: int or float
     """
-    def size(path):
-        return sum(file_size(f) for f in file_list(path))
+    def size(filepaths):
+        return sum(file_size(f) for f in filepaths
+                   if os.path.exists(f))
 
     # This should return mtime if file system was mounted with noatime.
     def atime(filepath):
@@ -82,36 +88,65 @@ def limit_directory_size(path, max_total_size):
         return statinfo.st_atime
 
     # Remove oldest file until `path` size is small enough
-    while size(path) > max_total_size:
-        files = sorted(file_list(path), key=atime)
+    filepaths = file_list(path, min_age=min_age, max_age=max_age)
+    while size(filepaths) > max_total_size:
+        oldest_file = sorted(filepaths, key=atime)[0]
+        try:
+            os.unlink(oldest_file)
+        except OSError as e:
+            if e.strerror:
+                raise RuntimeError(f'{oldest_file}: Failed to prune: {e.strerror}')
+            else:
+                raise RuntimeError(f'{oldest_file}: Failed to prune: {e}')
+        else:
+            filepaths = file_list(path, min_age=min_age, max_age=max_age)
+
+    prune_empty(path, files=True, directories=True)
+
+
+def prune_empty(path, files=False, directories=True):
+    """
+    Remove empty subdirectories recursively
+
+    :param path: Path to directory
+    :param bool files: Whether to prune empty files
+    :param bool directories: Whether to prune empty directories
+
+    If `path` is not a directory, do nothing.
+    """
+    if not os.path.isdir(path):
+        return
+
+    def raise_error(e, path):
+        if e.strerror:
+            raise RuntimeError(f'{path}: Failed to prune: {e.strerror}')
+        else:
+            raise RuntimeError(f'{path}: Failed to prune: {e}')
+
+    for dirpath, dirnames, filenames in os.walk(path, topdown=False):
         if files:
-            try:
-                os.unlink(files[0])
-            except OSError as e:
-                if e.strerror:
-                    raise RuntimeError(f'{files[0]}: Failed to prune: {e.strerror}')
-                else:
-                    raise RuntimeError(f'{files[0]}: Failed to prune: {e}')
-                break
+            for filename in filenames:
+                filepath = os.path.join(dirpath, filename)
+                try:
+                    if file_size(filepath) <= 0:
+                        os.unlink(filepath)
+                except OSError as e:
+                    raise_error(e, filepath)
 
-    prune_empty_directories(path)
-
-
-def prune_empty_directories(path):
-    """Remove empty subdirectories recursively"""
-    try:
-        for dirpath, dirnames, _ in os.walk(path, topdown=False):
+        if directories:
             for dirname in dirnames:
                 subdirpath = os.path.join(dirpath, dirname)
-                if not os.listdir(subdirpath):
-                    os.rmdir(subdirpath)
-        if not os.listdir(path):
+                try:
+                    if not os.listdir(subdirpath):
+                        os.rmdir(subdirpath)
+                except OSError as e:
+                    raise_error(e, subdirpath)
+
+    try:
+        if directories and not os.listdir(path):
             os.rmdir(path)
     except OSError as e:
-        if e.strerror:
-            raise RuntimeError(f'{subdirpath}: Failed to prune: {e.strerror}')
-        else:
-            raise RuntimeError(f'{subdirpath}: Failed to prune: {e}')
+        raise_error(e, path)
 
 
 def mkdir(path):
@@ -244,24 +279,33 @@ def file_size(path):
     return None
 
 
-def file_list(path, extensions=()):
+def file_list(path, extensions=(), min_age=None, max_age=None):
     """
     List naturally sorted files in `path` and any subdirectories
 
     If `path` is not a directory, it is returned as a single item in a list
     unless `extensions` are given and they don't match.
 
-    Unreadable directories are ignored.
+    Unreadable directories are excluded.
 
     :param str path: Path to a directory
-    :param str extensions: List of file extensions to include
+    :param str extensions: Exclude files without one of these extensions
+    :param min_age: Exclude files that are younger than this
+    :type min_age: int or float
+    :param max_age: Exclude files that are older than this
+    :type max_age: int or float
 
     :return: Tuple of file paths
     """
     extensions = tuple(str(e).casefold() for e in extensions)
 
     def ext_ok(filename):
-        return file_extension(filename).casefold() in extensions
+        return not extensions or file_extension(filename).casefold() in extensions
+
+    def age_ok(filepath, now=time.time()):
+        statinfo = os.stat(filepath)
+        age = round(now - statinfo.st_atime)
+        return (min_age or age) <= age <= (max_age or age)
 
     if not os.path.isdir(path):
         if ext_ok(path):
@@ -271,9 +315,10 @@ def file_list(path, extensions=()):
 
     files = []
     for root, dirnames, filenames in os.walk(path):
-        for filename in filenames:
-            if not extensions or ext_ok(filename):
-                files.append(os.path.join(root, filename))
+        for filename in sorted(filenames):
+            filepath = os.path.join(root, filename)
+            if ext_ok(filename) and age_ok(filepath):
+                files.append(filepath)
     return tuple(natsort.natsorted(files, key=str.casefold))
 
 
